@@ -4,11 +4,13 @@
 #'
 #' Download VIIRS nightlight tile
 #'
-#' @param nlYearMonth the year in "YYYYMM" format e.g. "201401"
+#' @param nlPeriod the nlPeriod of the tile to download
 #'
-#' @param tileNum the index of the tile as given by getNlTiles("VIIRS")
+#' @param tileNum the index of the tile as given by \code{getNlTiles}
 #' 
 #' @param downloadMethod The method to use for download.
+#' 
+#' @param nlType A character string of nlType
 #'
 #' @return TRUE/FALSE Whether the download was successful
 #'
@@ -18,36 +20,40 @@
 #'   print("download successful")
 #'   }
 #'
-downloadNlTilesVIIRS <- function(nlYearMonth, tileNum, downloadMethod=pkgOptions("downloadMethod"))
+downloadNlTilesVIIRS <- function(nlPeriod, tileNum, downloadMethod=pkgOptions("downloadMethod"), nlType)
 {
-  nlType <- "VIIRS"
-  
-  if(missing(nlYearMonth))
-    stop("Missing required parameter nlYear")
+  if(missing(nlPeriod))
+    stop("Missing required parameter nlPeriod")
   
   if(missing(tileNum))
     stop("Missing required parameter tileNum")
   
-  if(!validNlPeriodVIIRS(nlYearMonth))
-    stop("Invalid nlYear: ", nlYearMonth)
+  if(missing(nlType))
+    stop("Missing required parameter nlType")
   
-  if(!validNlTileNumVIIRS(tileNum))
+  if(!validNlTypes(nlType))
+    stop("Invalid nlType")
+  
+  if(!allValidNlPeriods(nlPeriods = nlPeriod, nlTypes = nlType))
+    stop("Invalid nlPeriod: ", nlPeriod)
+  
+  if(!validNlTileNumVIIRS(tileNum, nlType))
     stop("Invalid tileNum: ", tileNum)
   
   rsltDnld <- NA
   
   #get the zip and tif local names
-  ntLtsZipLocalNamePathVIIRS <- getNlTileZipLclNamePath("VIIRS", nlYearMonth, tileNum)
-  ntLtsTifLocalNamePathVIIRS <- getNlTileTifLclNamePath("VIIRS", nlYearMonth, tileNum)
+  ntLtsZipLocalNamePathVIIRS <- getNlTileZipLclNamePath(nlType, nlPeriod, tileNum)
+  ntLtsTifLocalNamePathVIIRS <- getNlTileTifLclNamePath(nlType, nlPeriod, tileNum)
 
   #if the .tif doesn't exist download tgz tile. For aria and wget, if the tgz exists
   #it should attempt to complete it if incomplete else confirm it is complete and move
   #to extraction. For the other methods it will restart the download and overwrite
   if (!file.exists(ntLtsTifLocalNamePathVIIRS))
   {
-    ntLtsFileUrl <- getNlUrlVIIRS(nlYearMonth, tileNum)
+    ntLtsFileUrl <- getNlUrlVIIRS(nlPeriod, tileNum, nlType)
     
-    validDnldMethods <- c(c("auto", "curl", "libcurl", "wget", "aria"))
+    validDnldMethods <- c(c("auto", "curl", "libcurl", "wget", "aria"), nlType)
     
     if (!(downloadMethod %in% validDnldMethods))
       downloadMethod <- "auto"
@@ -55,7 +61,7 @@ downloadNlTilesVIIRS <- function(nlYearMonth, tileNum, downloadMethod=pkgOptions
     if (downloadMethod %in% c("auto", "curl", "libcurl", "wget"))
       rsltDnld <- utils::download.file(ntLtsFileUrl, ntLtsZipLocalNamePathVIIRS, mode = "wb", method = downloadMethod, extra = "-c")
     else if (downloadMethod == "aria")
-      rsltDnld <- system(paste0("aria2c -c -x2 ", ntLtsFileUrl, " -d ", getNlDir("dirNlTiles"), " -o ", getNlTileZipLclNameVIIRS(nlYearMonth, tileNum))) #downloads to path relative to -d if specified else local dir
+      rsltDnld <- system(paste0("aria2c -c -x2 ", ntLtsFileUrl, " -d ", getNlDir("dirNlTiles"), " -o ", getNlTileZipLclNameVIIRS(nlPeriod, tileNum, nlType))) #downloads to path relative to -d if specified else local dir
   }
   else
   {
@@ -70,7 +76,18 @@ downloadNlTilesVIIRS <- function(nlYearMonth, tileNum, downloadMethod=pkgOptions
   {
     message("Extracting ", ntLtsZipLocalNamePathVIIRS, " ", base::date())
     
-    if (!file.exists(getNlTileTifLclNamePathVIIRS(nlYearMonth, tileNum)))
+    if(nlType == "VIIRS.D" && exists("ntLtsFileUrl"))
+    {
+      lenZipLclName <- nchar(ntLtsFileUrl)
+      extZipLclName <- substr(ntLtsFileUrl, lenZipLclName - 2, lenZipLclName)
+      
+      if(tolower(extZipLclName) != "tgz")
+      {
+        file.rename(ntLtsZipLocalNamePathVIIRS, ntLtsTifLocalNamePathVIIRS)
+      }
+    }
+    else
+      if (!file.exists(getNlTileTifLclNamePathVIIRS(nlPeriod, tileNum, nlType)))
     {
       message("Getting list of files in ", ntLtsZipLocalNamePathVIIRS, " ", base::date())
       
@@ -88,11 +105,11 @@ downloadNlTilesVIIRS <- function(nlYearMonth, tileNum, downloadMethod=pkgOptions
       
       message("Decompressing ", tgzAvgRadFilename, " ", base::date())
       
-      if(!file.exists(getNlTileTifLclNamePathVIIRS(nlYearMonth, tileNum)))
+      if(!file.exists(getNlTileTifLclNamePathVIIRS(nlPeriod, tileNum, nlType)))
       {
         utils::untar(ntLtsZipLocalNamePathVIIRS, files = tgzAvgRadFilename, exdir = getNlDir("dirNlTiles"), tar="internal")
         
-        file.rename(file.path(getNlDir("dirNlTiles"), tgzAvgRadFilename), getNlTileTifLclNamePathVIIRS(nlYearMonth, tileNum))
+        file.rename(file.path(getNlDir("dirNlTiles"), tgzAvgRadFilename), getNlTileTifLclNamePathVIIRS(nlPeriod, tileNum, nlType))
         
         unlink(ntLtsZipLocalNamePathVIIRS, force = TRUE)
       }
@@ -102,6 +119,11 @@ downloadNlTilesVIIRS <- function(nlYearMonth, tileNum, downloadMethod=pkgOptions
       message("TIF file found")
     }
   }
+  else
+  {
+    message("An error occurred downloading")
+    return(-1)
+  }
   
   return (rsltDnld == 0)
 }
@@ -112,7 +134,7 @@ downloadNlTilesVIIRS <- function(nlYearMonth, tileNum, downloadMethod=pkgOptions
 #'
 #' Download OLS nightlight tile
 #'
-#' @param nlYear the year in "YYYY" format e.g. "2012"
+#' @param nlPeriod the nlPeriod of the tile
 #'
 #' @param downloadMethod The method to use for download.
 #'
@@ -124,27 +146,27 @@ downloadNlTilesVIIRS <- function(nlYearMonth, tileNum, downloadMethod=pkgOptions
 #'   print("download successful")
 #'   }
 #'
-downloadNlTilesOLS <- function(nlYear, downloadMethod=pkgOptions("downloadMethod"))
+downloadNlTilesOLS <- function(nlPeriod, downloadMethod=pkgOptions("downloadMethod"))
 {
-  nlType <- "OLS"
+  nlType <- "OLS.Y"
   
-  if(missing(nlYear))
-    stop("Missing required parameter nlYear")
+  if(missing(nlPeriod))
+    stop("Missing required parameter nlPeriod")
   
-  if(!validNlPeriodOLS(nlYear))
-    stop("Invalid nlYear: ", nlYear)
+  if(!allValidNlPeriods(nlPeriods = nlPeriod, nlTypes = nlType))
+    stop("Invalid nlPeriod: ", nlPeriod)
   
   rsltDnld <- NA
   
   #get the zip and tif local names
-  ntLtsZipLocalNamePathOLS <- getNlTileZipLclNamePath("OLS", nlYear)
-  ntLtsTifLocalNamePathOLS <- getNlTileTifLclNamePath("OLS", nlYear)
+  ntLtsZipLocalNamePathOLS <- getNlTileZipLclNamePath(nlType, nlPeriod)
+  ntLtsTifLocalNamePathOLS <- getNlTileTifLclNamePath(nlType, nlPeriod)
   
   #if (!file.exists(ntLtsZipLocalNameVIIRS) && !file.exists(ntLtsTifLocalNameVIIRS))
   if (!file.exists(ntLtsTifLocalNamePathOLS))
   {
     #get the first only to cater for Where multiple tiles exist 
-    ntLtsFileUrl <- getNlUrlOLS(nlYear)[1]
+    ntLtsFileUrl <- getNlUrlOLS(nlPeriod)[1]
     
     ntLtsFileUrl <- gsub("\n", "", ntLtsFileUrl)
     
@@ -156,7 +178,7 @@ downloadNlTilesOLS <- function(nlYear, downloadMethod=pkgOptions("downloadMethod
     if (downloadMethod %in% c("auto", "curl", "libcurl", "wget"))
       rsltDnld <- utils::download.file(ntLtsFileUrl, ntLtsZipLocalNamePathOLS, mode = "wb", method = downloadMethod, extra = "-c")
     else if (downloadMethod == "aria")
-      rsltDnld <- system(paste0("aria2c -c -x2 ", ntLtsFileUrl, " -d ", getNlDir("dirNlTiles"), " -o ", getNlTileZipLclNameOLS(nlYear))) #downloads to path relative to -d if specified else local dir
+      rsltDnld <- system(paste0("aria2c -c -x2 ", ntLtsFileUrl, " -d ", getNlDir("dirNlTiles"), " -o ", getNlTileZipLclNameOLS(nlPeriod))) #downloads to path relative to -d if specified else local dir
     
   }
   else
@@ -174,7 +196,7 @@ downloadNlTilesOLS <- function(nlYear, downloadMethod=pkgOptions("downloadMethod
     
     tileNum <- "dummyTileNum"
     
-    if (!file.exists(getNlTileTifLclNamePathOLS(nlYear, tileNum)))
+    if (!file.exists(getNlTileTifLclNamePathOLS(nlPeriod, tileNum)))
     {
       message("Getting list of files in ", ntLtsZipLocalNamePathOLS, " ", base::date())
       
